summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--test/smp/cmake/regression/CMakeLists.txt4
-rw-r--r--test/smp/regression/testcontrol.c16
-rw-r--r--test/smp/regression/threadx_mutex_information_test.c36
-rw-r--r--test/smp/regression/threadx_mutex_nested_priority_inheritance_test.c4
-rw-r--r--test/smp/regression/threadx_smp_resume_suspend_accending_order_test.c76
-rw-r--r--test/smp/regression/threadx_smp_resume_suspend_decending_order_test.c144
-rw-r--r--test/smp/regression/threadx_thread_basic_execution_test.c4
-rw-r--r--test/smp/regression/threadx_thread_delayed_suspension_test.c20
-rw-r--r--test/smp/regression/threadx_thread_simple_suspend_test.c2
-rw-r--r--test/smp/regression/threadx_thread_sleep_for_100ticks_test.c28
-rw-r--r--test/smp/regression/threadx_thread_terminate_delete_test.c2
-rw-r--r--test/tx/regression/testcontrol.c8
-rw-r--r--test/tx/regression/threadx_mutex_information_test.c36
-rw-r--r--test/tx/regression/threadx_mutex_nested_priority_inheritance_test.c4
-rw-r--r--test/tx/regression/threadx_thread_basic_execution_test.c4
-rw-r--r--test/tx/regression/threadx_thread_delayed_suspension_test.c20
-rw-r--r--test/tx/regression/threadx_thread_simple_suspend_test.c2
-rw-r--r--test/tx/regression/threadx_thread_sleep_for_100ticks_test.c28
-rw-r--r--test/tx/regression/threadx_thread_terminate_delete_test.c2
19 files changed, 220 insertions, 220 deletions
diff --git a/test/smp/cmake/regression/CMakeLists.txt b/test/smp/cmake/regression/CMakeLists.txt
index c2362620..f7226c21 100644
--- a/test/smp/cmake/regression/CMakeLists.txt
+++ b/test/smp/cmake/regression/CMakeLists.txt
@@ -75,8 +75,8 @@ set(regression_test_cases
${SOURCE_DIR}/threadx_smp_random_resume_suspend_test.c
${SOURCE_DIR}/threadx_smp_rebalance_exclusion_test.c
${SOURCE_DIR}/threadx_smp_relinquish_test.c
- ${SOURCE_DIR}/threadx_smp_resume_suspend_accending_order_test.c
- ${SOURCE_DIR}/threadx_smp_resume_suspend_decending_order_test.c
+ ${SOURCE_DIR}/threadx_smp_resume_suspend_ascending_order_test.c
+ ${SOURCE_DIR}/threadx_smp_resume_suspend_descending_order_test.c
${SOURCE_DIR}/threadx_smp_time_slice_test.c
${SOURCE_DIR}/threadx_smp_two_threads_one_core_test.c
${SOURCE_DIR}/threadx_thread_basic_execution_test.c
diff --git a/test/smp/regression/testcontrol.c b/test/smp/regression/testcontrol.c
index 6b45750d..dacaf70e 100644
--- a/test/smp/regression/testcontrol.c
+++ b/test/smp/regression/testcontrol.c
@@ -209,7 +209,7 @@ void threadx_semaphore_information_application_define(void *);
void threadx_thread_basic_execution_application_define(void *);
void threadx_thread_completed_application_define(void *);
void threadx_thread_relinquish_application_define(void *);
-void threadx_thread_simple_supsend_application_define(void *);
+void threadx_thread_simple_suspend_application_define(void *);
void threadx_thread_multiple_suspension_application_define(void *);
void threadx_thread_multiple_non_current_suspension_application_define(void *);
void threadx_thread_multi_level_preemption_threshold_application_define(void *);
@@ -250,8 +250,8 @@ void threadx_smp_two_threads_one_core_test(void *first_unused_memory);
void threadx_smp_multiple_threads_one_core_test(void *first_unused_memory);
void threadx_smp_one_thread_dynamic_exclusion_test(void *first_unused_memory);
void threadx_smp_non_trivial_scheduling_test(void *first_unused_memory);
-void threadx_smp_resume_suspend_accending_order_test(void *first_unused_memory);
-void threadx_smp_resume_suspend_decending_order_test(void *first_unused_memory);
+void threadx_smp_resume_suspend_ascending_order_test(void *first_unused_memory);
+void threadx_smp_resume_suspend_descending_order_test(void *first_unused_memory);
void threadx_smp_preemption_threshold_test(void *first_unused_memory);
void threadx_smp_relinquish_test(void *first_unused_memory);
void threadx_smp_time_slice_test(void *first_unused_memory);
@@ -274,8 +274,8 @@ TEST_ENTRY test_control_tests[] =
threadx_smp_multiple_threads_one_core_test,
threadx_smp_one_thread_dynamic_exclusion_test,
threadx_smp_non_trivial_scheduling_test,
- threadx_smp_resume_suspend_accending_order_test,
- threadx_smp_resume_suspend_decending_order_test,
+ threadx_smp_resume_suspend_ascending_order_test,
+ threadx_smp_resume_suspend_descending_order_test,
threadx_smp_preemption_threshold_test,
threadx_smp_relinquish_test,
threadx_smp_time_slice_test,
@@ -353,7 +353,7 @@ TEST_ENTRY test_control_tests[] =
threadx_thread_basic_execution_application_define,
threadx_thread_completed_application_define,
threadx_thread_relinquish_application_define,
- threadx_thread_simple_supsend_application_define,
+ threadx_thread_simple_suspend_application_define,
threadx_thread_multiple_suspension_application_define,
threadx_thread_multiple_non_current_suspension_application_define,
threadx_thread_multi_level_preemption_threshold_application_define,
@@ -1429,8 +1429,8 @@ UINT old_posture = TX_INT_ENABLE;
/* Are interrupts disabled? */
if (old_posture == TX_INT_DISABLE)
{
-
- /* System error - interrupts should alwasy be enabled in our test threads! */
+
+ /* System error - interrupts should always be enabled in our test threads! */
printf(" ***** SYSTEM ERROR ***** test returned with interrupts disabled!\n");
test_control_system_errors++;
}
diff --git a/test/smp/regression/threadx_mutex_information_test.c b/test/smp/regression/threadx_mutex_information_test.c
index 55503002..74f4714b 100644
--- a/test/smp/regression/threadx_mutex_information_test.c
+++ b/test/smp/regression/threadx_mutex_information_test.c
@@ -312,7 +312,7 @@ ULONG inheritances;
test_control_return(1);
}
- /* Now get the performance inforamtion. */
+ /* Now get the performance information. */
status = tx_mutex_performance_info_get(&mutex_2, &puts, &gets, &suspensions, &timeouts, &inversions, &inheritances);
/* Check status. */
@@ -325,8 +325,8 @@ ULONG inheritances;
printf("ERROR #19\n");
test_control_return(1);
}
-
- /* Now get the system performance inforamtion. */
+
+ /* Now get the system performance information. */
status = tx_mutex_performance_system_info_get(&puts, &gets, &suspensions, &timeouts, &inversions, &inheritances);
/* Check status. */
@@ -342,7 +342,7 @@ ULONG inheritances;
#else
- /* Now get the performance inforamtion. */
+ /* Now get the performance information. */
status = tx_mutex_performance_info_get(&mutex_2, &puts, &gets, &suspensions, &timeouts, &inversions, &inheritances);
/* Check status. */
@@ -354,7 +354,7 @@ ULONG inheritances;
test_control_return(1);
}
- /* Now get the performance inforamtion. */
+ /* Now get the performance information. */
status = tx_mutex_performance_info_get(TX_NULL, &puts, &gets, &suspensions, &timeouts, &inversions, &inheritances);
/* Check status. */
@@ -366,7 +366,7 @@ ULONG inheritances;
test_control_return(1);
}
- /* Now get the performance inforamtion. */
+ /* Now get the performance information. */
status = tx_mutex_performance_info_get(TX_NULL, TX_NULL, &gets, &suspensions, &timeouts, &inversions, &inheritances);
/* Check status. */
@@ -378,7 +378,7 @@ ULONG inheritances;
test_control_return(1);
}
- /* Now get the performance inforamtion. */
+ /* Now get the performance information. */
status = tx_mutex_performance_info_get(TX_NULL, TX_NULL, TX_NULL, &suspensions, &timeouts, &inversions, &inheritances);
/* Check status. */
@@ -390,7 +390,7 @@ ULONG inheritances;
test_control_return(1);
}
- /* Now get the performance inforamtion. */
+ /* Now get the performance information. */
status = tx_mutex_performance_info_get(TX_NULL, TX_NULL, TX_NULL, TX_NULL, &timeouts, &inversions, &inheritances);
/* Check status. */
@@ -402,7 +402,7 @@ ULONG inheritances;
test_control_return(1);
}
- /* Now get the performance inforamtion. */
+ /* Now get the performance information. */
status = tx_mutex_performance_info_get(TX_NULL, TX_NULL, TX_NULL, TX_NULL, TX_NULL, &inversions, &inheritances);
/* Check status. */
@@ -414,7 +414,7 @@ ULONG inheritances;
test_control_return(1);
}
- /* Now get the performance inforamtion. */
+ /* Now get the performance information. */
status = tx_mutex_performance_info_get(TX_NULL, TX_NULL, TX_NULL, TX_NULL, TX_NULL, TX_NULL, &inheritances);
/* Check status. */
@@ -426,7 +426,7 @@ ULONG inheritances;
test_control_return(1);
}
- /* Now get the performance inforamtion. */
+ /* Now get the performance information. */
status = tx_mutex_performance_info_get(TX_NULL, TX_NULL, TX_NULL, TX_NULL, TX_NULL, TX_NULL, TX_NULL);
/* Check status. */
@@ -438,7 +438,7 @@ ULONG inheritances;
test_control_return(1);
}
- /* Now get the system performance inforamtion. */
+ /* Now get the system performance information. */
status = tx_mutex_performance_system_info_get(&puts, &gets, &suspensions, &timeouts, &inversions, &inheritances);
/* Check status. */
@@ -450,7 +450,7 @@ ULONG inheritances;
test_control_return(1);
}
- /* Now get the system performance inforamtion. */
+ /* Now get the system performance information. */
status = tx_mutex_performance_system_info_get(TX_NULL, &gets, &suspensions, &timeouts, &inversions, &inheritances);
/* Check status. */
@@ -462,7 +462,7 @@ ULONG inheritances;
test_control_return(1);
}
- /* Now get the system performance inforamtion. */
+ /* Now get the system performance information. */
status = tx_mutex_performance_system_info_get(TX_NULL, TX_NULL, &suspensions, &timeouts, &inversions, &inheritances);
/* Check status. */
@@ -474,7 +474,7 @@ ULONG inheritances;
test_control_return(1);
}
- /* Now get the system performance inforamtion. */
+ /* Now get the system performance information. */
status = tx_mutex_performance_system_info_get(TX_NULL, TX_NULL, TX_NULL, &timeouts, &inversions, &inheritances);
/* Check status. */
@@ -486,7 +486,7 @@ ULONG inheritances;
test_control_return(1);
}
- /* Now get the system performance inforamtion. */
+ /* Now get the system performance information. */
status = tx_mutex_performance_system_info_get(TX_NULL, TX_NULL, TX_NULL, TX_NULL, &inversions, &inheritances);
/* Check status. */
@@ -498,7 +498,7 @@ ULONG inheritances;
test_control_return(1);
}
- /* Now get the system performance inforamtion. */
+ /* Now get the system performance information. */
status = tx_mutex_performance_system_info_get(TX_NULL, TX_NULL, TX_NULL, TX_NULL, TX_NULL, &inheritances);
/* Check status. */
@@ -510,7 +510,7 @@ ULONG inheritances;
test_control_return(1);
}
- /* Now get the system performance inforamtion. */
+ /* Now get the system performance information. */
status = tx_mutex_performance_system_info_get(TX_NULL, TX_NULL, TX_NULL, TX_NULL, TX_NULL, TX_NULL);
/* Check status. */
diff --git a/test/smp/regression/threadx_mutex_nested_priority_inheritance_test.c b/test/smp/regression/threadx_mutex_nested_priority_inheritance_test.c
index 1439ca85..e9b60bf5 100644
--- a/test/smp/regression/threadx_mutex_nested_priority_inheritance_test.c
+++ b/test/smp/regression/threadx_mutex_nested_priority_inheritance_test.c
@@ -404,7 +404,7 @@ UINT status;
tx_mutex_put(&mutex_2);
- /* Should reurn us back to priority 15. */
+ /* Should return us back to priority 15. */
if (thread_0.tx_thread_priority != 15)
{
@@ -441,7 +441,7 @@ UINT status;
tx_mutex_put(&mutex_2);
- /* Should reurn us back to priority 8. */
+ /* Should return us back to priority 8. */
if (thread_0.tx_thread_priority != 8)
{
diff --git a/test/smp/regression/threadx_thread_basic_execution_test.c b/test/smp/regression/threadx_thread_basic_execution_test.c
index 5772f97e..f10ce2e9 100644
--- a/test/smp/regression/threadx_thread_basic_execution_test.c
+++ b/test/smp/regression/threadx_thread_basic_execution_test.c
@@ -741,7 +741,7 @@ VOID (*temp_mutex_release)(TX_THREAD *thread_ptr);
test_control_return(1);
}
- /* Attempt a thread termiante with a NULL pointer. */
+ /* Attempt a thread terminate with a NULL pointer. */
status = tx_thread_terminate(TX_NULL);
/* Check for status. */
@@ -764,7 +764,7 @@ VOID (*temp_mutex_release)(TX_THREAD *thread_ptr);
test_control_return(1);
}
- /* Attempt a thread time-slice chagne with a NULL pointer. */
+ /* Attempt a thread time-slice change with a NULL pointer. */
status = tx_thread_time_slice_change(TX_NULL, 1, &old_time_slice);
/* Check for status. */
diff --git a/test/smp/regression/threadx_thread_simple_suspend_test.c b/test/smp/regression/threadx_thread_simple_suspend_test.c
index a05797ec..2e21d056 100644
--- a/test/smp/regression/threadx_thread_simple_suspend_test.c
+++ b/test/smp/regression/threadx_thread_simple_suspend_test.c
@@ -25,7 +25,7 @@ void test_control_return(UINT status);
#ifdef CTEST
void test_application_define(void *first_unused_memory)
#else
-void threadx_thread_simple_supsend_application_define(void *first_unused_memory)
+void threadx_thread_simple_suspend_application_define(void *first_unused_memory)
#endif
{
diff --git a/test/smp/regression/threadx_thread_terminate_delete_test.c b/test/smp/regression/threadx_thread_terminate_delete_test.c
index 63fd6a69..15e25e7d 100644
--- a/test/smp/regression/threadx_thread_terminate_delete_test.c
+++ b/test/smp/regression/threadx_thread_terminate_delete_test.c
@@ -244,7 +244,7 @@ UINT status;
test_control_return(1);
}
- /* Delete thread 1 (thread 1 alread terminated) and 2. */
+ /* Delete thread 1 (thread 1 alreadyterminated) and 2. */
status = tx_thread_delete(&thread_2);
/* Check for status. */
diff --git a/test/tx/regression/testcontrol.c b/test/tx/regression/testcontrol.c
index 3d33bc7f..4944784a 100644
--- a/test/tx/regression/testcontrol.c
+++ b/test/tx/regression/testcontrol.c
@@ -195,7 +195,7 @@ void threadx_semaphore_information_application_define(void *);
void threadx_thread_basic_execution_application_define(void *);
void threadx_thread_completed_application_define(void *);
void threadx_thread_relinquish_application_define(void *);
-void threadx_thread_simple_supsend_application_define(void *);
+void threadx_thread_simple_suspend_application_define(void *);
void threadx_thread_multiple_suspension_application_define(void *);
void threadx_thread_multiple_non_current_suspension_application_define(void *);
void threadx_thread_multi_level_preemption_threshold_application_define(void *);
@@ -312,7 +312,7 @@ TEST_ENTRY test_control_tests[] =
threadx_thread_basic_execution_application_define,
threadx_thread_completed_application_define,
threadx_thread_relinquish_application_define,
- threadx_thread_simple_supsend_application_define,
+ threadx_thread_simple_suspend_application_define,
threadx_thread_multiple_suspension_application_define,
threadx_thread_multiple_non_current_suspension_application_define,
threadx_thread_multi_level_preemption_threshold_application_define,
@@ -1232,8 +1232,8 @@ UINT old_posture = TX_INT_ENABLE;
/* Are interrupts disabled? */
if (old_posture == TX_INT_DISABLE)
{
-
- /* System error - interrupts should alwasy be enabled in our test threads! */
+
+ /* System error - interrupts should always be enabled in our test threads! */
printf(" ***** SYSTEM ERROR ***** test returned with interrupts disabled!\n");
test_control_system_errors++;
}
diff --git a/test/tx/regression/threadx_mutex_information_test.c b/test/tx/regression/threadx_mutex_information_test.c
index 55503002..74f4714b 100644
--- a/test/tx/regression/threadx_mutex_information_test.c
+++ b/test/tx/regression/threadx_mutex_information_test.c
@@ -312,7 +312,7 @@ ULONG inheritances;
test_control_return(1);
}
- /* Now get the performance inforamtion. */
+ /* Now get the performance information. */
status = tx_mutex_performance_info_get(&mutex_2, &puts, &gets, &suspensions, &timeouts, &inversions, &inheritances);
/* Check status. */
@@ -325,8 +325,8 @@ ULONG inheritances;
printf("ERROR #19\n");
test_control_return(1);
}
-
- /* Now get the system performance inforamtion. */
+
+ /* Now get the system performance information. */
status = tx_mutex_performance_system_info_get(&puts, &gets, &suspensions, &timeouts, &inversions, &inheritances);
/* Check status. */
@@ -342,7 +342,7 @@ ULONG inheritances;
#else
- /* Now get the performance inforamtion. */
+ /* Now get the performance information. */
status = tx_mutex_performance_info_get(&mutex_2, &puts, &gets, &suspensions, &timeouts, &inversions, &inheritances);
/* Check status. */
@@ -354,7 +354,7 @@ ULONG inheritances;
test_control_return(1);
}
- /* Now get the performance inforamtion. */
+ /* Now get the performance information. */
status = tx_mutex_performance_info_get(TX_NULL, &puts, &gets, &suspensions, &timeouts, &inversions, &inheritances);
/* Check status. */
@@ -366,7 +366,7 @@ ULONG inheritances;
test_control_return(1);
}
- /* Now get the performance inforamtion. */
+ /* Now get the performance information. */
status = tx_mutex_performance_info_get(TX_NULL, TX_NULL, &gets, &suspensions, &timeouts, &inversions, &inheritances);
/* Check status. */
@@ -378,7 +378,7 @@ ULONG inheritances;
test_control_return(1);
}
- /* Now get the performance inforamtion. */
+ /* Now get the performance information. */
status = tx_mutex_performance_info_get(TX_NULL, TX_NULL, TX_NULL, &suspensions, &timeouts, &inversions, &inheritances);
/* Check status. */
@@ -390,7 +390,7 @@ ULONG inheritances;
test_control_return(1);
}
- /* Now get the performance inforamtion. */
+ /* Now get the performance information. */
status = tx_mutex_performance_info_get(TX_NULL, TX_NULL, TX_NULL, TX_NULL, &timeouts, &inversions, &inheritances);
/* Check status. */
@@ -402,7 +402,7 @@ ULONG inheritances;
test_control_return(1);
}
- /* Now get the performance inforamtion. */
+ /* Now get the performance information. */
status = tx_mutex_performance_info_get(TX_NULL, TX_NULL, TX_NULL, TX_NULL, TX_NULL, &inversions, &inheritances);
/* Check status. */
@@ -414,7 +414,7 @@ ULONG inheritances;
test_control_return(1);
}
- /* Now get the performance inforamtion. */
+ /* Now get the performance information. */
status = tx_mutex_performance_info_get(TX_NULL, TX_NULL, TX_NULL, TX_NULL, TX_NULL, TX_NULL, &inheritances);
/* Check status. */
@@ -426,7 +426,7 @@ ULONG inheritances;
test_control_return(1);
}
- /* Now get the performance inforamtion. */
+ /* Now get the performance information. */
status = tx_mutex_performance_info_get(TX_NULL, TX_NULL, TX_NULL, TX_NULL, TX_NULL, TX_NULL, TX_NULL);
/* Check status. */
@@ -438,7 +438,7 @@ ULONG inheritances;
test_control_return(1);
}
- /* Now get the system performance inforamtion. */
+ /* Now get the system performance information. */
status = tx_mutex_performance_system_info_get(&puts, &gets, &suspensions, &timeouts, &inversions, &inheritances);
/* Check status. */
@@ -450,7 +450,7 @@ ULONG inheritances;
test_control_return(1);
}
- /* Now get the system performance inforamtion. */
+ /* Now get the system performance information. */
status = tx_mutex_performance_system_info_get(TX_NULL, &gets, &suspensions, &timeouts, &inversions, &inheritances);
/* Check status. */
@@ -462,7 +462,7 @@ ULONG inheritances;
test_control_return(1);
}
- /* Now get the system performance inforamtion. */
+ /* Now get the system performance information. */
status = tx_mutex_performance_system_info_get(TX_NULL, TX_NULL, &suspensions, &timeouts, &inversions, &inheritances);
/* Check status. */
@@ -474,7 +474,7 @@ ULONG inheritances;
test_control_return(1);
}
- /* Now get the system performance inforamtion. */
+ /* Now get the system performance information. */
status = tx_mutex_performance_system_info_get(TX_NULL, TX_NULL, TX_NULL, &timeouts, &inversions, &inheritances);
/* Check status. */
@@ -486,7 +486,7 @@ ULONG inheritances;
test_control_return(1);
}
- /* Now get the system performance inforamtion. */
+ /* Now get the system performance information. */
status = tx_mutex_performance_system_info_get(TX_NULL, TX_NULL, TX_NULL, TX_NULL, &inversions, &inheritances);
/* Check status. */
@@ -498,7 +498,7 @@ ULONG inheritances;
test_control_return(1);
}
- /* Now get the system performance inforamtion. */
+ /* Now get the system performance information. */
status = tx_mutex_performance_system_info_get(TX_NULL, TX_NULL, TX_NULL, TX_NULL, TX_NULL, &inheritances);
/* Check status. */
@@ -510,7 +510,7 @@ ULONG inheritances;
test_control_return(1);
}
- /* Now get the system performance inforamtion. */
+ /* Now get the system performance information. */
status = tx_mutex_performance_system_info_get(TX_NULL, TX_NULL, TX_NULL, TX_NULL, TX_NULL, TX_NULL);
/* Check status. */
diff --git a/test/tx/regression/threadx_mutex_nested_priority_inheritance_test.c b/test/tx/regression/threadx_mutex_nested_priority_inheritance_test.c
index 1439ca85..e9b60bf5 100644
--- a/test/tx/regression/threadx_mutex_nested_priority_inheritance_test.c
+++ b/test/tx/regression/threadx_mutex_nested_priority_inheritance_test.c
@@ -404,7 +404,7 @@ UINT status;
tx_mutex_put(&mutex_2);
- /* Should reurn us back to priority 15. */
+ /* Should return us back to priority 15. */
if (thread_0.tx_thread_priority != 15)
{
@@ -441,7 +441,7 @@ UINT status;
tx_mutex_put(&mutex_2);
- /* Should reurn us back to priority 8. */
+ /* Should return us back to priority 8. */
if (thread_0.tx_thread_priority != 8)
{
diff --git a/test/tx/regression/threadx_thread_basic_execution_test.c b/test/tx/regression/threadx_thread_basic_execution_test.c
index 9949eac8..af2c8fa1 100644
--- a/test/tx/regression/threadx_thread_basic_execution_test.c
+++ b/test/tx/regression/threadx_thread_basic_execution_test.c
@@ -813,7 +813,7 @@ VOID (*temp_mutex_release)(TX_THREAD *thread_ptr);
test_control_return(1);
}
- /* Attempt a thread termiante with a NULL pointer. */
+ /* Attempt a thread terminate with a NULL pointer. */
status = tx_thread_terminate(TX_NULL);
/* Check for status. */
@@ -836,7 +836,7 @@ VOID (*temp_mutex_release)(TX_THREAD *thread_ptr);
test_control_return(1);
}
- /* Attempt a thread time-slice chagne with a NULL pointer. */
+ /* Attempt a thread time-slice change with a NULL pointer. */
status = tx_thread_time_slice_change(TX_NULL, 1, &old_time_slice);
/* Check for status. */
diff --git a/test/tx/regression/threadx_thread_simple_suspend_test.c b/test/tx/regression/threadx_thread_simple_suspend_test.c
index a05797ec..2e21d056 100644
--- a/test/tx/regression/threadx_thread_simple_suspend_test.c
+++ b/test/tx/regression/threadx_thread_simple_suspend_test.c
@@ -25,7 +25,7 @@ void test_control_return(UINT status);
#ifdef CTEST
void test_application_define(void *first_unused_memory)
#else
-void threadx_thread_simple_supsend_application_define(void *first_unused_memory)
+void threadx_thread_simple_suspend_application_define(void *first_unused_memory)
#endif
{
diff --git a/test/tx/regression/threadx_thread_terminate_delete_test.c b/test/tx/regression/threadx_thread_terminate_delete_test.c
index 63fd6a69..15e25e7d 100644
--- a/test/tx/regression/threadx_thread_terminate_delete_test.c
+++ b/test/tx/regression/threadx_thread_terminate_delete_test.c
@@ -244,7 +244,7 @@ UINT status;
test_control_return(1);
}
- /* Delete thread 1 (thread 1 alread terminated) and 2. */
+ /* Delete thread 1 (thread 1 alreadyterminated) and 2. */
status = tx_thread_delete(&thread_2);
/* Check for status. */
diff --git a/test/smp/regression/threadx_smp_resume_suspend_accending_order_test.c b/test/smp/regression/threadx_smp_resume_suspend_accending_order_test.c
index fe55660a..22140ab5 100644
--- a/test/smp/regression/threadx_smp_resume_suspend_accending_order_test.c
+++ b/test/smp/regression/threadx_smp_resume_suspend_accending_order_test.c
@@ -1,4 +1,4 @@
/* Define the ThreadX SMP resume and suspend threads in accending order test. */
#include <stdio.h>
#include "tx_api.h"
@@ -71,7 +71,7 @@ static void delay(UINT i)
#ifdef CTEST
void test_application_define(void *first_unused_memory)
#else
-void threadx_smp_resume_suspend_accending_order_test(void *first_unused_memory)
+void threadx_smp_resume_suspend_ascending_order_test(void *first_unused_memory)
#endif
{
@@ -969,7 +969,7 @@ UINT status;
test_control_return(1);
}
/* Suspend thread in accending priority. */
delay(1);
status = tx_thread_suspend(&thread_1);
@@ -982,8 +982,8 @@ UINT status;
printf("ERROR #65\n");
test_control_return(1);
}
-
- /* Suspend thread in accending priority. */
+
+ /* Suspend thread in ascending priority. */
delay(2);
status = tx_thread_suspend(&thread_2);
@@ -997,7 +997,7 @@ UINT status;
test_control_return(1);
}
/* Suspend thread in accending priority. */
delay(3);
status = tx_thread_suspend(&thread_3);
@@ -1011,7 +1011,7 @@ UINT status;
test_control_return(1);
}
/* Suspend thread in accending priority. */
delay(4);
status = tx_thread_suspend(&thread_4);
@@ -1025,7 +1025,7 @@ UINT status;
test_control_return(1);
}
/* Suspend thread in accending priority. */
delay(5);
status = tx_thread_suspend(&thread_5);
@@ -1039,7 +1039,7 @@ UINT status;
test_control_return(1);
}
/* Suspend thread in accending priority. */
delay(6);
status = tx_thread_suspend(&thread_6);
@@ -1053,7 +1053,7 @@ UINT status;
test_control_return(1);
}
/* Suspend thread in accending priority. */
delay(7);
status = tx_thread_suspend(&thread_7);
@@ -1067,7 +1067,7 @@ UINT status;
test_control_return(1);
}
/* Suspend thread in accending priority. */
delay(8);
status = tx_thread_suspend(&thread_8);
@@ -1081,7 +1081,7 @@ UINT status;
test_control_return(1);
}
/* Suspend thread in accending priority. */
delay(9);
status = tx_thread_suspend(&thread_9);
@@ -1095,7 +1095,7 @@ UINT status;
test_control_return(1);
}
/* Suspend thread in accending priority. */
delay(10);
status = tx_thread_suspend(&thread_10);
@@ -1109,7 +1109,7 @@ UINT status;
test_control_return(1);
}
/* Suspend thread in accending priority. */
delay(11);
status = tx_thread_suspend(&thread_11);
@@ -1123,7 +1123,7 @@ UINT status;
test_control_return(1);
}
/* Suspend thread in accending priority. */
delay(12);
status = tx_thread_suspend(&thread_12);
@@ -1137,7 +1137,7 @@ UINT status;
test_control_return(1);
}
/* Suspend thread in accending priority. */
delay(13);
status = tx_thread_suspend(&thread_13);
@@ -1150,8 +1150,8 @@ UINT status;
printf("ERROR #77\n");
test_control_return(1);
}
-
- /* Suspend thread in accending priority. */
+
+ /* Suspend thread in ascending priority. */
delay(14);
status = tx_thread_suspend(&thread_14);
@@ -1164,8 +1164,8 @@ UINT status;
printf("ERROR #78\n");
test_control_return(1);
}
-
- /* Suspend thread in accending priority. */
+
+ /* Suspend thread in ascending priority. */
delay(15);
status = tx_thread_suspend(&thread_15);
@@ -1178,8 +1178,8 @@ UINT status;
printf("ERROR #79\n");
test_control_return(1);
}
-
- /* Suspend thread in accending priority. */
+
+ /* Suspend thread in ascending priority. */
delay(16);
status = tx_thread_suspend(&thread_16);
@@ -1193,7 +1193,7 @@ UINT status;
test_control_return(1);
}
/* Suspend thread in accending priority. */
delay(17);
status = tx_thread_suspend(&thread_17);
@@ -1206,8 +1206,8 @@ UINT status;
printf("ERROR #81\n");
test_control_return(1);
}
-
- /* Suspend thread in accending priority. */
+
+ /* Suspend thread in ascending priority. */
delay(18);
status = tx_thread_suspend(&thread_18);
@@ -1221,7 +1221,7 @@ UINT status;
test_control_return(1);
}
/* Suspend thread in accending priority. */
delay(19);
status = tx_thread_suspend(&thread_19);
@@ -1235,7 +1235,7 @@ UINT status;
test_control_return(1);
}
/* Suspend thread in accending priority. */
delay(20);
status = tx_thread_suspend(&thread_20);
@@ -1249,7 +1249,7 @@ UINT status;
test_control_return(1);
}
/* Suspend thread in accending priority. */
delay(21);
status = tx_thread_suspend(&thread_21);
@@ -1263,7 +1263,7 @@ UINT status;
test_control_return(1);
}
/* Suspend thread in accending priority. */
delay(22);
status = tx_thread_suspend(&thread_22);
@@ -1277,7 +1277,7 @@ UINT status;
test_control_return(1);
}
/* Suspend thread in accending priority. */
delay(23);
status = tx_thread_suspend(&thread_23);
@@ -1291,7 +1291,7 @@ UINT status;
test_control_return(1);
}
/* Suspend thread in accending priority. */
delay(24);
status = tx_thread_suspend(&thread_24);
@@ -1305,7 +1305,7 @@ UINT status;
test_control_return(1);
}
/* Suspend thread in accending priority. */
delay(25);
status = tx_thread_suspend(&thread_25);
@@ -1319,7 +1319,7 @@ UINT status;
test_control_return(1);
}
/* Suspend thread in accending priority. */
delay(26);
status = tx_thread_suspend(&thread_26);
@@ -1333,7 +1333,7 @@ UINT status;
test_control_return(1);
}
/* Suspend thread in accending priority. */
delay(27);
status = tx_thread_suspend(&thread_27);
@@ -1347,7 +1347,7 @@ UINT status;
test_control_return(1);
}
/* Suspend thread in accending priority. */
delay(28);
status = tx_thread_suspend(&thread_28);
@@ -1361,7 +1361,7 @@ UINT status;
test_control_return(1);
}
/* Suspend thread in accending priority. */
delay(29);
status = tx_thread_suspend(&thread_29);
@@ -1375,7 +1375,7 @@ UINT status;
test_control_return(1);
}
/* Suspend thread in accending priority. */
delay(30);
status = tx_thread_suspend(&thread_30);
@@ -1389,7 +1389,7 @@ UINT status;
test_control_return(1);
}
/* Suspend thread in accending priority. */
delay(31);
status = tx_thread_suspend(&thread_31);
@@ -1,4 +1,4 @@
-/* Define the ThreadX SMP resume and suspend threads in accending order test. */
+/* Define the ThreadX SMP resume and suspend threads in ascending order test. */
#include <stdio.h>
#include "tx_api.h"
@@ -969,7 +969,7 @@ UINT status;
test_control_return(1);
}
- /* Suspend thread in accending priority. */
+ /* Suspend thread in ascending priority. */
delay(1);
status = tx_thread_suspend(&thread_1);
@@ -997,7 +997,7 @@ UINT status;
test_control_return(1);
}
- /* Suspend thread in accending priority. */
+ /* Suspend thread in ascending priority. */
delay(3);
status = tx_thread_suspend(&thread_3);
@@ -1011,7 +1011,7 @@ UINT status;
test_control_return(1);
}
- /* Suspend thread in accending priority. */
+ /* Suspend thread in ascending priority. */
delay(4);
status = tx_thread_suspend(&thread_4);
@@ -1025,7 +1025,7 @@ UINT status;
test_control_return(1);
}
- /* Suspend thread in accending priority. */
+ /* Suspend thread in ascending priority. */
delay(5);
status = tx_thread_suspend(&thread_5);
@@ -1039,7 +1039,7 @@ UINT status;
test_control_return(1);
}
- /* Suspend thread in accending priority. */
+ /* Suspend thread in ascending priority. */
delay(6);
status = tx_thread_suspend(&thread_6);
@@ -1053,7 +1053,7 @@ UINT status;
test_control_return(1);
}
- /* Suspend thread in accending priority. */
+ /* Suspend thread in ascending priority. */
delay(7);
status = tx_thread_suspend(&thread_7);
@@ -1067,7 +1067,7 @@ UINT status;
test_control_return(1);
}
- /* Suspend thread in accending priority. */
+ /* Suspend thread in ascending priority. */
delay(8);
status = tx_thread_suspend(&thread_8);
@@ -1081,7 +1081,7 @@ UINT status;
test_control_return(1);
}
- /* Suspend thread in accending priority. */
+ /* Suspend thread in ascending priority. */
delay(9);
status = tx_thread_suspend(&thread_9);
@@ -1095,7 +1095,7 @@ UINT status;
test_control_return(1);
}
- /* Suspend thread in accending priority. */
+ /* Suspend thread in ascending priority. */
delay(10);
status = tx_thread_suspend(&thread_10);
@@ -1109,7 +1109,7 @@ UINT status;
test_control_return(1);
}
- /* Suspend thread in accending priority. */
+ /* Suspend thread in ascending priority. */
delay(11);
status = tx_thread_suspend(&thread_11);
@@ -1123,7 +1123,7 @@ UINT status;
test_control_return(1);
}
- /* Suspend thread in accending priority. */
+ /* Suspend thread in ascending priority. */
delay(12);
status = tx_thread_suspend(&thread_12);
@@ -1137,7 +1137,7 @@ UINT status;
test_control_return(1);
}
- /* Suspend thread in accending priority. */
+ /* Suspend thread in ascending priority. */
delay(13);
status = tx_thread_suspend(&thread_13);
@@ -1193,7 +1193,7 @@ UINT status;
test_control_return(1);
}
- /* Suspend thread in accending priority. */
+ /* Suspend thread in ascending priority. */
delay(17);
status = tx_thread_suspend(&thread_17);
@@ -1221,7 +1221,7 @@ UINT status;
test_control_return(1);
}
- /* Suspend thread in accending priority. */
+ /* Suspend thread in ascending priority. */
delay(19);
status = tx_thread_suspend(&thread_19);
@@ -1235,7 +1235,7 @@ UINT status;
test_control_return(1);
}
- /* Suspend thread in accending priority. */
+ /* Suspend thread in ascending priority. */
delay(20);
status = tx_thread_suspend(&thread_20);
@@ -1249,7 +1249,7 @@ UINT status;
test_control_return(1);
}
- /* Suspend thread in accending priority. */
+ /* Suspend thread in ascending priority. */
delay(21);
status = tx_thread_suspend(&thread_21);
@@ -1263,7 +1263,7 @@ UINT status;
test_control_return(1);
}
- /* Suspend thread in accending priority. */
+ /* Suspend thread in ascending priority. */
delay(22);
status = tx_thread_suspend(&thread_22);
@@ -1277,7 +1277,7 @@ UINT status;
test_control_return(1);
}
- /* Suspend thread in accending priority. */
+ /* Suspend thread in ascending priority. */
delay(23);
status = tx_thread_suspend(&thread_23);
@@ -1291,7 +1291,7 @@ UINT status;
test_control_return(1);
}
- /* Suspend thread in accending priority. */
+ /* Suspend thread in ascending priority. */
delay(24);
status = tx_thread_suspend(&thread_24);
@@ -1305,7 +1305,7 @@ UINT status;
test_control_return(1);
}
- /* Suspend thread in accending priority. */
+ /* Suspend thread in ascending priority. */
delay(25);
status = tx_thread_suspend(&thread_25);
@@ -1319,7 +1319,7 @@ UINT status;
test_control_return(1);
}
- /* Suspend thread in accending priority. */
+ /* Suspend thread in ascending priority. */
delay(26);
status = tx_thread_suspend(&thread_26);
@@ -1333,7 +1333,7 @@ UINT status;
test_control_return(1);
}
- /* Suspend thread in accending priority. */
+ /* Suspend thread in ascending priority. */
delay(27);
status = tx_thread_suspend(&thread_27);
@@ -1347,7 +1347,7 @@ UINT status;
test_control_return(1);
}
- /* Suspend thread in accending priority. */
+ /* Suspend thread in ascending priority. */
delay(28);
status = tx_thread_suspend(&thread_28);
@@ -1361,7 +1361,7 @@ UINT status;
test_control_return(1);
}
- /* Suspend thread in accending priority. */
+ /* Suspend thread in ascending priority. */
delay(29);
status = tx_thread_suspend(&thread_29);
@@ -1375,7 +1375,7 @@ UINT status;
test_control_return(1);
}
- /* Suspend thread in accending priority. */
+ /* Suspend thread in ascending priority. */
delay(30);
status = tx_thread_suspend(&thread_30);
@@ -1389,7 +1389,7 @@ UINT status;
test_control_return(1);
}
- /* Suspend thread in accending priority. */
+ /* Suspend thread in ascending priority. */
delay(31);
status = tx_thread_suspend(&thread_31);
diff --git a/test/smp/regression/threadx_smp_resume_suspend_decending_order_test.c b/test/smp/regression/threadx_smp_resume_suspend_decending_order_test.c
index 83b6f141..a269796f 100644
--- a/test/smp/regression/threadx_smp_resume_suspend_decending_order_test.c
+++ b/test/smp/regression/threadx_smp_resume_suspend_decending_order_test.c
@@ -1,4 +1,4 @@
-/* Define the ThreadX SMP resume and suspend threads in accending order test. */
+/* Define the ThreadX SMP resume and suspend threads in ascending order test. */
#include <stdio.h>
#include "tx_api.h"
@@ -71,7 +71,7 @@ static void delay(UINT i)
#ifdef CTEST
void test_application_define(void *first_unused_memory)
#else
-void threadx_smp_resume_suspend_decending_order_test(void *first_unused_memory)
+void threadx_smp_resume_suspend_descending_order_test(void *first_unused_memory)
#endif
{
@@ -96,7 +96,7 @@ UINT i;
if (status != TX_SUCCESS)
{
- printf("Running SMP Resume-Suspend Decending Priority Order Test............ ERROR #1\n");
+ printf("Running SMP Resume-Suspend descending Priority Order Test............ ERROR #1\n");
test_control_return(1);
}
@@ -110,7 +110,7 @@ UINT i;
if (status != TX_SUCCESS)
{
- printf("Running SMP Resume-Suspend Decending Priority Order Test............ ERROR #2\n");
+ printf("Running SMP Resume-Suspend descending Priority Order Test............ ERROR #2\n");
test_control_return(1);
}
@@ -124,7 +124,7 @@ UINT i;
if (status != TX_SUCCESS)
{
- printf("Running SMP Resume-Suspend Decending Priority Order Test............ ERROR #3\n");
+ printf("Running SMP Resume-Suspend descending Priority Order Test............ ERROR #3\n");
test_control_return(1);
}
@@ -138,7 +138,7 @@ UINT i;
if (status != TX_SUCCESS)
{
- printf("Running SMP Resume-Suspend Decending Priority Order Test............ ERROR #4\n");
+ printf("Running SMP Resume-Suspend descending Priority Order Test............ ERROR #4\n");
test_control_return(1);
}
@@ -152,7 +152,7 @@ UINT i;
if (status != TX_SUCCESS)
{
- printf("Running SMP Resume-Suspend Decending Priority Order Test............ ERROR #5\n");
+ printf("Running SMP Resume-Suspend descending Priority Order Test............ ERROR #5\n");
test_control_return(1);
}
@@ -166,7 +166,7 @@ UINT i;
if (status != TX_SUCCESS)
{
- printf("Running SMP Resume-Suspend Decending Priority Order Test............ ERROR #6\n");
+ printf("Running SMP Resume-Suspend descending Priority Order Test............ ERROR #6\n");
test_control_return(1);
}
@@ -180,7 +180,7 @@ UINT i;
if (status != TX_SUCCESS)
{
- printf("Running SMP Resume-Suspend Decending Priority Order Test............ ERROR #7\n");
+ printf("Running SMP Resume-Suspend descending Priority Order Test............ ERROR #7\n");
test_control_return(1);
}
@@ -194,7 +194,7 @@ UINT i;
if (status != TX_SUCCESS)
{
- printf("Running SMP Resume-Suspend Decending Priority Order Test............ ERROR #8\n");
+ printf("Running SMP Resume-Suspend descending Priority Order Test............ ERROR #8\n");
test_control_return(1);
}
@@ -208,7 +208,7 @@ UINT i;
if (status != TX_SUCCESS)
{
- printf("Running SMP Resume-Suspend Decending Priority Order Test............ ERROR #9\n");
+ printf("Running SMP Resume-Suspend descending Priority Order Test............ ERROR #9\n");
test_control_return(1);
}
@@ -222,7 +222,7 @@ UINT i;
if (status != TX_SUCCESS)
{
- printf("Running SMP Resume-Suspend Decending Priority Order Test............ ERROR #9\n");
+ printf("Running SMP Resume-Suspend descending Priority Order Test............ ERROR #9\n");
test_control_return(1);
}
@@ -236,7 +236,7 @@ UINT i;
if (status != TX_SUCCESS)
{
- printf("Running SMP Resume-Suspend Decending Priority Order Test............ ERROR #11\n");
+ printf("Running SMP Resume-Suspend descending Priority Order Test............ ERROR #11\n");
test_control_return(1);
}
@@ -250,7 +250,7 @@ UINT i;
if (status != TX_SUCCESS)
{
- printf("Running SMP Resume-Suspend Decending Priority Order Test............ ERROR #12\n");
+ printf("Running SMP Resume-Suspend descending Priority Order Test............ ERROR #12\n");
test_control_return(1);
}
@@ -264,7 +264,7 @@ UINT i;
if (status != TX_SUCCESS)
{
- printf("Running SMP Resume-Suspend Decending Priority Order Test............ ERROR #13\n");
+ printf("Running SMP Resume-Suspend descending Priority Order Test............ ERROR #13\n");
test_control_return(1);
}
@@ -278,7 +278,7 @@ UINT i;
if (status != TX_SUCCESS)
{
- printf("Running SMP Resume-Suspend Decending Priority Order Test............ ERROR #14\n");
+ printf("Running SMP Resume-Suspend descending Priority Order Test............ ERROR #14\n");
test_control_return(1);
}
@@ -292,7 +292,7 @@ UINT i;
if (status != TX_SUCCESS)
{
- printf("Running SMP Resume-Suspend Decending Priority Order Test............ ERROR #15\n");
+ printf("Running SMP Resume-Suspend descending Priority Order Test............ ERROR #15\n");
test_control_return(1);
}
@@ -306,7 +306,7 @@ UINT i;
if (status != TX_SUCCESS)
{
- printf("Running SMP Resume-Suspend Decending Priority Order Test............ ERROR #16\n");
+ printf("Running SMP Resume-Suspend descending Priority Order Test............ ERROR #16\n");
test_control_return(1);
}
@@ -320,7 +320,7 @@ UINT i;
if (status != TX_SUCCESS)
{
- printf("Running SMP Resume-Suspend Decending Priority Order Test............ ERROR #17\n");
+ printf("Running SMP Resume-Suspend descending Priority Order Test............ ERROR #17\n");
test_control_return(1);
}
@@ -334,7 +334,7 @@ UINT i;
if (status != TX_SUCCESS)
{
- printf("Running SMP Resume-Suspend Decending Priority Order Test............ ERROR #18\n");
+ printf("Running SMP Resume-Suspend descending Priority Order Test............ ERROR #18\n");
test_control_return(1);
}
@@ -348,7 +348,7 @@ UINT i;
if (status != TX_SUCCESS)
{
- printf("Running SMP Resume-Suspend Decending Priority Order Test............ ERROR #19\n");
+ printf("Running SMP Resume-Suspend descending Priority Order Test............ ERROR #19\n");
test_control_return(1);
}
@@ -362,7 +362,7 @@ UINT i;
if (status != TX_SUCCESS)
{
- printf("Running SMP Resume-Suspend Decending Priority Order Test............ ERROR #20\n");
+ printf("Running SMP Resume-Suspend descending Priority Order Test............ ERROR #20\n");
test_control_return(1);
}
@@ -376,7 +376,7 @@ UINT i;
if (status != TX_SUCCESS)
{
- printf("Running SMP Resume-Suspend Decending Priority Order Test............ ERROR #21\n");
+ printf("Running SMP Resume-Suspend descending Priority Order Test............ ERROR #21\n");
test_control_return(1);
}
@@ -390,7 +390,7 @@ UINT i;
if (status != TX_SUCCESS)
{
- printf("Running SMP Resume-Suspend Decending Priority Order Test............ ERROR #22\n");
+ printf("Running SMP Resume-Suspend descending Priority Order Test............ ERROR #22\n");
test_control_return(1);
}
@@ -404,7 +404,7 @@ UINT i;
if (status != TX_SUCCESS)
{
- printf("Running SMP Resume-Suspend Decending Priority Order Test............ ERROR #23\n");
+ printf("Running SMP Resume-Suspend descending Priority Order Test............ ERROR #23\n");
test_control_return(1);
}
@@ -418,7 +418,7 @@ UINT i;
if (status != TX_SUCCESS)
{
- printf("Running SMP Resume-Suspend Decending Priority Order Test............ ERROR #24\n");
+ printf("Running SMP Resume-Suspend descending Priority Order Test............ ERROR #24\n");
test_control_return(1);
}
@@ -432,7 +432,7 @@ UINT i;
if (status != TX_SUCCESS)
{
- printf("Running SMP Resume-Suspend Decending Priority Order Test............ ERROR #25\n");
+ printf("Running SMP Resume-Suspend descending Priority Order Test............ ERROR #25\n");
test_control_return(1);
}
@@ -446,7 +446,7 @@ UINT i;
if (status != TX_SUCCESS)
{
- printf("Running SMP Resume-Suspend Decending Priority Order Test............ ERROR #26\n");
+ printf("Running SMP Resume-Suspend descending Priority Order Test............ ERROR #26\n");
test_control_return(1);
}
@@ -460,7 +460,7 @@ UINT i;
if (status != TX_SUCCESS)
{
- printf("Running SMP Resume-Suspend Decending Priority Order Test............ ERROR #27\n");
+ printf("Running SMP Resume-Suspend descending Priority Order Test............ ERROR #27\n");
test_control_return(1);
}
@@ -474,7 +474,7 @@ UINT i;
if (status != TX_SUCCESS)
{
- printf("Running SMP Resume-Suspend Decending Priority Order Test............ ERROR #28\n");
+ printf("Running SMP Resume-Suspend descending Priority Order Test............ ERROR #28\n");
test_control_return(1);
}
@@ -488,7 +488,7 @@ UINT i;
if (status != TX_SUCCESS)
{
- printf("Running SMP Resume-Suspend Decending Priority Order Test............ ERROR #29\n");
+ printf("Running SMP Resume-Suspend descending Priority Order Test............ ERROR #29\n");
test_control_return(1);
}
@@ -502,7 +502,7 @@ UINT i;
if (status != TX_SUCCESS)
{
- printf("Running SMP Resume-Suspend Decending Priority Order Test............ ERROR #30\n");
+ printf("Running SMP Resume-Suspend descending Priority Order Test............ ERROR #30\n");
test_control_return(1);
}
@@ -516,7 +516,7 @@ UINT i;
if (status != TX_SUCCESS)
{
- printf("Running SMP Resume-Suspend Decending Priority Order Test............ ERROR #31\n");
+ printf("Running SMP Resume-Suspend descending Priority Order Test............ ERROR #31\n");
test_control_return(1);
}
@@ -530,7 +530,7 @@ UINT i;
if (status != TX_SUCCESS)
{
- printf("Running SMP Resume-Suspend Decending Priority Order Test............ ERROR #32\n");
+ printf("Running SMP Resume-Suspend descending Priority Order Test............ ERROR #32\n");
test_control_return(1);
}
@@ -547,7 +547,7 @@ UINT i;
if (status != TX_SUCCESS)
{
- printf("Running SMP Resume-Suspend Decending Priority Order Test............ ERROR #33\n");
+ printf("Running SMP Resume-Suspend descending Priority Order Test............ ERROR #33\n");
test_control_return(1);
}
}
@@ -564,7 +564,7 @@ UINT status;
/* Inform user. */
- printf("Running SMP Resume-Suspend Decending Priority Order Test............ ");
+ printf("Running SMP Resume-Suspend descending Priority Order Test............ ");
/* Resume all the threads. */
status = tx_thread_resume(&thread_31);
@@ -999,7 +999,7 @@ UINT status;
test_control_return(1);
}
/* Suspend thread in decending priority. */
status = tx_thread_suspend(&thread_31);
/* Check for the correct results. */
@@ -1011,8 +1011,8 @@ UINT status;
printf("ERROR #65\n");
test_control_return(1);
}
-
- /* Suspend thread in accending priority. */
+
+ /* Suspend thread in ascending priority. */
status = tx_thread_suspend(&thread_30);
/* Check for the correct results. */
@@ -1025,7 +1025,7 @@ UINT status;
test_control_return(1);
}
- /* Suspend thread in accending priority. */
+ /* Suspend thread in ascending priority. */
status = tx_thread_suspend(&thread_29);
/* Check for the correct results. */
@@ -1038,7 +1038,7 @@ UINT status;
test_control_return(1);
}
- /* Suspend thread in accending priority. */
+ /* Suspend thread in ascending priority. */
status = tx_thread_suspend(&thread_28);
/* Check for the correct results. */
@@ -1051,7 +1051,7 @@ UINT status;
test_control_return(1);
}
- /* Suspend thread in accending priority. */
+ /* Suspend thread in ascending priority. */
status = tx_thread_suspend(&thread_27);
/* Check for the correct results. */
@@ -1064,7 +1064,7 @@ UINT status;
test_control_return(1);
}
- /* Suspend thread in accending priority. */
+ /* Suspend thread in ascending priority. */
status = tx_thread_suspend(&thread_26);
/* Check for the correct results. */
@@ -1077,7 +1077,7 @@ UINT status;
test_control_return(1);
}
- /* Suspend thread in accending priority. */
+ /* Suspend thread in ascending priority. */
status = tx_thread_suspend(&thread_25);
/* Check for the correct results. */
@@ -1090,7 +1090,7 @@ UINT status;
test_control_return(1);
}
- /* Suspend thread in accending priority. */
+ /* Suspend thread in ascending priority. */
status = tx_thread_suspend(&thread_24);
/* Check for the correct results. */
@@ -1103,7 +1103,7 @@ UINT status;
test_control_return(1);
}
- /* Suspend thread in accending priority. */
+ /* Suspend thread in ascending priority. */
status = tx_thread_suspend(&thread_23);
/* Check for the correct results. */
@@ -1116,7 +1116,7 @@ UINT status;
test_control_return(1);
}
- /* Suspend thread in accending priority. */
+ /* Suspend thread in ascending priority. */
status = tx_thread_suspend(&thread_22);
/* Check for the correct results. */
@@ -1129,7 +1129,7 @@ UINT status;
test_control_return(1);
}
- /* Suspend thread in accending priority. */
+ /* Suspend thread in ascending priority. */
status = tx_thread_suspend(&thread_21);
/* Check for the correct results. */
@@ -1142,7 +1142,7 @@ UINT status;
test_control_return(1);
}
- /* Suspend thread in accending priority. */
+ /* Suspend thread in ascending priority. */
status = tx_thread_suspend(&thread_20);
/* Check for the correct results. */
@@ -1155,7 +1155,7 @@ UINT status;
test_control_return(1);
}
- /* Suspend thread in accending priority. */
+ /* Suspend thread in ascending priority. */
status = tx_thread_suspend(&thread_19);
/* Check for the correct results. */
@@ -1167,8 +1167,8 @@ UINT status;
printf("ERROR #77\n");
test_control_return(1);
}
-
- /* Suspend thread in accending priority. */
+
+ /* Suspend thread in ascending priority. */
status = tx_thread_suspend(&thread_18);
/* Check for the correct results. */
@@ -1180,8 +1180,8 @@ UINT status;
printf("ERROR #78\n");
test_control_return(1);
}
-
- /* Suspend thread in accending priority. */
+
+ /* Suspend thread in ascending priority. */
status = tx_thread_suspend(&thread_17);
/* Check for the correct results. */
@@ -1193,8 +1193,8 @@ UINT status;
printf("ERROR #79\n");
test_control_return(1);
}
-
- /* Suspend thread in accending priority. */
+
+ /* Suspend thread in ascending priority. */
status = tx_thread_suspend(&thread_16);
/* Check for the correct results. */
@@ -1207,7 +1207,7 @@ UINT status;
test_control_return(1);
}
- /* Suspend thread in accending priority. */
+ /* Suspend thread in ascending priority. */
status = tx_thread_suspend(&thread_15);
/* Check for the correct results. */
@@ -1219,8 +1219,8 @@ UINT status;
printf("ERROR #81\n");
test_control_return(1);
}
-
- /* Suspend thread in accending priority. */
+
+ /* Suspend thread in ascending priority. */
status = tx_thread_suspend(&thread_14);
/* Check for the correct results. */
@@ -1233,7 +1233,7 @@ UINT status;
test_control_return(1);
}
- /* Suspend thread in accending priority. */
+ /* Suspend thread in ascending priority. */
status = tx_thread_suspend(&thread_13);
/* Check for the correct results. */
@@ -1246,7 +1246,7 @@ UINT status;
test_control_return(1);
}
- /* Suspend thread in accending priority. */
+ /* Suspend thread in ascending priority. */
status = tx_thread_suspend(&thread_12);
/* Check for the correct results. */
@@ -1259,7 +1259,7 @@ UINT status;
test_control_return(1);
}
- /* Suspend thread in accending priority. */
+ /* Suspend thread in ascending priority. */
status = tx_thread_suspend(&thread_11);
/* Check for the correct results. */
@@ -1272,7 +1272,7 @@ UINT status;
test_control_return(1);
}
- /* Suspend thread in accending priority. */
+ /* Suspend thread in ascending priority. */
status = tx_thread_suspend(&thread_10);
/* Check for the correct results. */
@@ -1285,7 +1285,7 @@ UINT status;
test_control_return(1);
}
- /* Suspend thread in accending priority. */
+ /* Suspend thread in ascending priority. */
status = tx_thread_suspend(&thread_9);
/* Check for the correct results. */
@@ -1298,7 +1298,7 @@ UINT status;
test_control_return(1);
}
- /* Suspend thread in accending priority. */
+ /* Suspend thread in ascending priority. */
status = tx_thread_suspend(&thread_8);
/* Check for the correct results. */
@@ -1311,7 +1311,7 @@ UINT status;
test_control_return(1);
}
- /* Suspend thread in accending priority. */
+ /* Suspend thread in ascending priority. */
status = tx_thread_suspend(&thread_7);
/* Check for the correct results. */
@@ -1324,7 +1324,7 @@ UINT status;
test_control_return(1);
}
- /* Suspend thread in accending priority. */
+ /* Suspend thread in ascending priority. */
status = tx_thread_suspend(&thread_6);
/* Check for the correct results. */
@@ -1337,7 +1337,7 @@ UINT status;
test_control_return(1);
}
- /* Suspend thread in accending priority. */
+ /* Suspend thread in ascending priority. */
status = tx_thread_suspend(&thread_5);
/* Check for the correct results. */
@@ -1350,7 +1350,7 @@ UINT status;
test_control_return(1);
}
- /* Suspend thread in accending priority. */
+ /* Suspend thread in ascending priority. */
status = tx_thread_suspend(&thread_4);
/* Check for the correct results. */
@@ -1363,7 +1363,7 @@ UINT status;
test_control_return(1);
}
- /* Suspend thread in accending priority. */
+ /* Suspend thread in ascending priority. */
status = tx_thread_suspend(&thread_3);
/* Check for the correct results. */
@@ -1376,7 +1376,7 @@ UINT status;
test_control_return(1);
}
- /* Suspend thread in accending priority. */
+ /* Suspend thread in ascending priority. */
status = tx_thread_suspend(&thread_2);
/* Check for the correct results. */
@@ -1389,7 +1389,7 @@ UINT status;
test_control_return(1);
}
- /* Suspend thread in accending priority. */
+ /* Suspend thread in ascending priority. */
status = tx_thread_suspend(&thread_1);
/* Check for the correct results. */
@@ -999,7 +999,7 @@ UINT status;
test_control_return(1);
}
- /* Suspend thread in decending priority. */
+ /* Suspend thread in descending priority. */
status = tx_thread_suspend(&thread_31);
/* Check for the correct results. */
diff --git a/test/smp/regression/threadx_thread_delayed_suspension_test.c b/test/smp/regression/threadx_thread_delayed_suspension_test.c
index 91128f83..e5d1e091 100644
--- a/test/smp/regression/threadx_thread_delayed_suspension_test.c
+++ b/test/smp/regression/threadx_thread_delayed_suspension_test.c
@@ -56,7 +56,7 @@ static volatile ULONG destination = 0;
static ULONG start_time;
static ULONG lower_bound;
static ULONG upper_bound;
-static ULONG current_itterations;
+static ULONG current_iterations;
#ifdef DEBUG_1
static ULONG last_loop_count;
#endif
@@ -106,9 +106,9 @@ ULONG i;
if (upper_bound > max_loop_count)
lower_bound = max_loop_count;
- if ((current_itterations < lower_bound) || (current_itterations > upper_bound))
- current_itterations = lower_bound;
-
+ if ((current_iterations < lower_bound) || (current_iterations > upper_bound))
+ current_iterations = lower_bound;
+
#ifdef DEBUG_1
/* Last loop count. */
last_loop_count = loop_count;
@@ -350,7 +350,7 @@ ULONG i;
lower_bound = lower_bound - 5;
upper_bound = max_loop_count + 5;
- current_itterations = lower_bound;
+ current_iterations = lower_bound;
/* This thread simply suspends over and over... */
while(1)
@@ -366,20 +366,20 @@ ULONG i;
/* Call delay function. */
delay_function();
loop_count++;
- } while (loop_count < current_itterations);
+ } while (loop_count < current_iterations);
/* Suspend this thread. */
tx_semaphore_get(&semaphore_1, TX_WAIT_FOREVER);
- /* Adjust the current itterations. */
- current_itterations++;
- if (current_itterations > upper_bound)
+ /* Adjust the current iterations. */
+ current_iterations++;
+ if (current_iterations > upper_bound)
{
if (lower_bound > min_loop_count)
lower_bound--;
if (upper_bound < max_loop_count)
upper_bound++;
- current_itterations = lower_bound;
+ current_iterations = lower_bound;
}
/* Increment the thread counter. */
diff --git a/test/smp/regression/threadx_thread_sleep_for_100ticks_test.c b/test/smp/regression/threadx_thread_sleep_for_100ticks_test.c
index d5c335f0..34467246 100644
--- a/test/smp/regression/threadx_thread_sleep_for_100ticks_test.c
+++ b/test/smp/regression/threadx_thread_sleep_for_100ticks_test.c
@@ -42,7 +42,7 @@ static ULONG array_delay[ARRAY_SIZE];
static ULONG start_time;
static ULONG lower_bound;
static ULONG upper_bound;
-static ULONG current_itterations;
+static ULONG current_iterations;
#ifdef DEBUG_1
static ULONG last_loop_count;
#endif
@@ -108,9 +108,9 @@ ULONG i;
if (upper_bound > max_loop_count)
lower_bound = max_loop_count;
- if ((current_itterations < lower_bound) || (current_itterations > upper_bound))
- current_itterations = lower_bound;
-
+ if ((current_iterations < lower_bound) || (current_iterations > upper_bound))
+ current_iterations = lower_bound;
+
#ifdef DEBUG_1
/* Last loop count. */
last_loop_count = loop_count;
@@ -218,7 +218,7 @@ CHAR *pointer;
min_loop_count = 0xFFFFFFFF;
max_loop_count = 0;
loop_count = 0xFFFFFFFF;
- current_itterations = 0;
+ current_iterations = 0;
#ifdef DEBUG_1
last_loop_count = 0x0;
#endif
@@ -305,7 +305,7 @@ volatile ULONG value = 0;
upper_bound = max_loop_count;
#endif
- current_itterations = lower_bound;
+ current_iterations = lower_bound;
#ifdef DEBUG
i = 0;
#endif
@@ -323,7 +323,7 @@ volatile ULONG value = 0;
/* Call delay function. */
delay_function();
loop_count++;
- } while (loop_count < current_itterations);
+ } while (loop_count < current_iterations);
/* Check for a timer interrupt... if so, just skip the semaphore get. */
if (start_time != _tx_timer_system_clock)
@@ -331,16 +331,16 @@ volatile ULONG value = 0;
/* Suspend on the semaphore for 20 ticks... */
tx_semaphore_get(&test_semaphore, 20);
-
- /* Adjust the current itterations. */
- current_itterations++;
- if (current_itterations > upper_bound)
+
+ /* Adjust the current iterations. */
+ current_iterations++;
+ if (current_iterations > upper_bound)
{
if (lower_bound > min_loop_count)
lower_bound--;
if (upper_bound < max_loop_count)
upper_bound++;
- current_itterations = lower_bound;
+ current_iterations = lower_bound;
}
/* Set the tick count simply to use value. */
@@ -355,7 +355,7 @@ volatile ULONG value = 0;
printf("loop count: NA\n");
else
printf("loop count: %lu\n", loop_count);
- printf("current: %lu\n", current_itterations);
+ printf("current: %lu\n", current_iterations);
printf("last loop count: %lu\n", last_loop_count);
printf("minimum: %lu\n", min_loop_count);
printf("maximum: %lu\n", max_loop_count);
@@ -373,7 +373,7 @@ volatile ULONG value = 0;
printf("loop count: NA\n");
else
printf("loop count: %lu\n", loop_count);
- printf("current: %lu\n", current_itterations);
+ printf("current: %lu\n", current_iterations);
printf("last loop count: %lu\n", last_loop_count);
printf("minimum: %lu\n", min_loop_count);
printf("maximum: %lu\n", max_loop_count);
diff --git a/test/tx/regression/threadx_thread_delayed_suspension_test.c b/test/tx/regression/threadx_thread_delayed_suspension_test.c
index 91128f83..e5d1e091 100644
--- a/test/tx/regression/threadx_thread_delayed_suspension_test.c
+++ b/test/tx/regression/threadx_thread_delayed_suspension_test.c
@@ -56,7 +56,7 @@ static volatile ULONG destination = 0;
static ULONG start_time;
static ULONG lower_bound;
static ULONG upper_bound;
-static ULONG current_itterations;
+static ULONG current_iterations;
#ifdef DEBUG_1
static ULONG last_loop_count;
#endif
@@ -106,9 +106,9 @@ ULONG i;
if (upper_bound > max_loop_count)
lower_bound = max_loop_count;
- if ((current_itterations < lower_bound) || (current_itterations > upper_bound))
- current_itterations = lower_bound;
-
+ if ((current_iterations < lower_bound) || (current_iterations > upper_bound))
+ current_iterations = lower_bound;
+
#ifdef DEBUG_1
/* Last loop count. */
last_loop_count = loop_count;
@@ -350,7 +350,7 @@ ULONG i;
lower_bound = lower_bound - 5;
upper_bound = max_loop_count + 5;
- current_itterations = lower_bound;
+ current_iterations = lower_bound;
/* This thread simply suspends over and over... */
while(1)
@@ -366,20 +366,20 @@ ULONG i;
/* Call delay function. */
delay_function();
loop_count++;
- } while (loop_count < current_itterations);
+ } while (loop_count < current_iterations);
/* Suspend this thread. */
tx_semaphore_get(&semaphore_1, TX_WAIT_FOREVER);
- /* Adjust the current itterations. */
- current_itterations++;
- if (current_itterations > upper_bound)
+ /* Adjust the current iterations. */
+ current_iterations++;
+ if (current_iterations > upper_bound)
{
if (lower_bound > min_loop_count)
lower_bound--;
if (upper_bound < max_loop_count)
upper_bound++;
- current_itterations = lower_bound;
+ current_iterations = lower_bound;
}
/* Increment the thread counter. */
diff --git a/test/tx/regression/threadx_thread_sleep_for_100ticks_test.c b/test/tx/regression/threadx_thread_sleep_for_100ticks_test.c
index d5c335f0..34467246 100644
--- a/test/tx/regression/threadx_thread_sleep_for_100ticks_test.c
+++ b/test/tx/regression/threadx_thread_sleep_for_100ticks_test.c
@@ -42,7 +42,7 @@ static ULONG array_delay[ARRAY_SIZE];
static ULONG start_time;
static ULONG lower_bound;
static ULONG upper_bound;
-static ULONG current_itterations;
+static ULONG current_iterations;
#ifdef DEBUG_1
static ULONG last_loop_count;
#endif
@@ -108,9 +108,9 @@ ULONG i;
if (upper_bound > max_loop_count)
lower_bound = max_loop_count;
- if ((current_itterations < lower_bound) || (current_itterations > upper_bound))
- current_itterations = lower_bound;
-
+ if ((current_iterations < lower_bound) || (current_iterations > upper_bound))
+ current_iterations = lower_bound;
+
#ifdef DEBUG_1
/* Last loop count. */
last_loop_count = loop_count;
@@ -218,7 +218,7 @@ CHAR *pointer;
min_loop_count = 0xFFFFFFFF;
max_loop_count = 0;
loop_count = 0xFFFFFFFF;
- current_itterations = 0;
+ current_iterations = 0;
#ifdef DEBUG_1
last_loop_count = 0x0;
#endif
@@ -305,7 +305,7 @@ volatile ULONG value = 0;
upper_bound = max_loop_count;
#endif
- current_itterations = lower_bound;
+ current_iterations = lower_bound;
#ifdef DEBUG
i = 0;
#endif
@@ -323,7 +323,7 @@ volatile ULONG value = 0;
/* Call delay function. */
delay_function();
loop_count++;
- } while (loop_count < current_itterations);
+ } while (loop_count < current_iterations);
/* Check for a timer interrupt... if so, just skip the semaphore get. */
if (start_time != _tx_timer_system_clock)
@@ -331,16 +331,16 @@ volatile ULONG value = 0;
/* Suspend on the semaphore for 20 ticks... */
tx_semaphore_get(&test_semaphore, 20);
-
- /* Adjust the current itterations. */
- current_itterations++;
- if (current_itterations > upper_bound)
+
+ /* Adjust the current iterations. */
+ current_iterations++;
+ if (current_iterations > upper_bound)
{
if (lower_bound > min_loop_count)
lower_bound--;
if (upper_bound < max_loop_count)
upper_bound++;
- current_itterations = lower_bound;
+ current_iterations = lower_bound;
}
/* Set the tick count simply to use value. */
@@ -355,7 +355,7 @@ volatile ULONG value = 0;
printf("loop count: NA\n");
else
printf("loop count: %lu\n", loop_count);
- printf("current: %lu\n", current_itterations);
+ printf("current: %lu\n", current_iterations);
printf("last loop count: %lu\n", last_loop_count);
printf("minimum: %lu\n", min_loop_count);
printf("maximum: %lu\n", max_loop_count);
@@ -373,7 +373,7 @@ volatile ULONG value = 0;
printf("loop count: NA\n");
else
printf("loop count: %lu\n", loop_count);
- printf("current: %lu\n", current_itterations);
+ printf("current: %lu\n", current_iterations);
printf("last loop count: %lu\n", last_loop_count);
printf("minimum: %lu\n", min_loop_count);
printf("maximum: %lu\n", max_loop_count);